==> synfig-1.0.tar.gz: synfig-1.0/src/modules/mod_example/filledrect.h <==
/* === S Y N F I G ========================================================= */
/*!	\file filledrect.h
**	\brief Header file for implementation of the "Rectangle" layer
**
**	$Id$
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_FILLEDRECT_H
#define __SYNFIG_FILLEDRECT_H

/* === H E A D E R S ======================================================= */

#include <synfig/layer_composite.h>
#include <synfig/color.h>
#include <synfig/vector.h>
#include <synfig/value.h>
#include <list>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

using namespace synfig;
using namespace std;
using namespace etl;

class FilledRect : public Layer_Composite, public Layer_NoDeform
{
	SYNFIG_LAYER_MODULE_EXT

private:
	//! Parameter: (Color)
	ValueBase param_color;
	//! Parameter: (Point)
	ValueBase param_point1;
	//! Parameter: (Point)
	ValueBase param_point2;
	//! Parameter: Real)
	ValueBase param_feather_x;
	//! Parameter: (Real)
	ValueBase param_feather_y;
	//! Parameter: (Real)
	ValueBase param_bevel;
	//! Parameter: (bool)
	ValueBase param_bevCircle;

	bool get_color(const Point &pos, Color &out, Real &outamount)const;

public:

	FilledRect();

	virtual bool set_param(const String & param, const ValueBase &value);

	virtual ValueBase get_param(const String & param)const;

	virtual Color get_color(Context context, const Point &pos)const;

	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
	virtual bool accelerated_cairorender(Context context, cairo_t *cr, int quality, const RendDesc &renddesc, ProgressCallback *cb)const;

	virtual Vocab get_param_vocab()const;

	virtual Layer::Handle hit_check(Context context, const Point &point)const;
}; // END of class FilledRect

/* === E N D =============================================================== */

#endif

==> synfig_1.0.2.orig.tar.gz: synfig-1.0.2/src/modules/mod_example/filledrect.h <==
/* === S Y N F I G ========================================================= */
/*!	\file filledrect.h
**	\brief Header file for implementation of the "Rectangle" layer
**
**	$Id$
**
**	\legal
**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
**
**	This package is free software; you can redistribute it and/or
**	modify it under the terms of the GNU General Public License as
**	published by the Free Software Foundation; either version 2 of
**	the License, or (at your option) any later version.
**
**	This package is distributed in the hope that it will be useful,
**	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
**	General Public License for more details.
**	\endlegal
*/
/* ========================================================================= */

/* === S T A R T =========================================================== */

#ifndef __SYNFIG_FILLEDRECT_H
#define __SYNFIG_FILLEDRECT_H

/* === H E A D E R S ======================================================= */

#include <synfig/layers/layer_composite.h>
#include <synfig/color.h>
#include <synfig/vector.h>
#include <synfig/value.h>
#include <list>

/* === M A C R O S ========================================================= */

/* === T Y P E D E F S ===================================================== */

/* === C L A S S E S & S T R U C T S ======================================= */

using namespace synfig;
using namespace std;
using namespace etl;

class FilledRect : public Layer_Composite, public Layer_NoDeform
{
	SYNFIG_LAYER_MODULE_EXT

private:
	//! Parameter: (Color)
	ValueBase param_color;
	//! Parameter: (Point)
	ValueBase param_point1;
	//! Parameter: (Point)
	ValueBase param_point2;
	//! Parameter: Real)
	ValueBase param_feather_x;
	//! Parameter: (Real)
	ValueBase param_feather_y;
	//! Parameter: (Real)
	ValueBase param_bevel;
	//! Parameter: (bool)
	ValueBase param_bevCircle;

	bool get_color(const Point &pos, Color &out, Real &outamount)const;

public:

	FilledRect();

	virtual bool set_param(const String & param, const ValueBase &value);

	virtual ValueBase get_param(const String & param)const;

	virtual Color get_color(Context context, const Point &pos)const;

	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
	virtual bool accelerated_cairorender(Context context, cairo_t *cr, int quality, const RendDesc &renddesc, ProgressCallback *cb)const;

	virtual Vocab get_param_vocab()const;

	virtual Layer::Handle hit_check(Context context, const Point &point)const;
}; // END of class FilledRect

/* === E N D =============================================================== */

#endif
